==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/PARTGREENHOUSEGASID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PARTGREENHOUSEGASID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PARTGREENHOUSEGASID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GREENHOUSEGASID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTGREENHOUSEGASID_Type", propOrder = {
    "partid",
    "greenhousegasid"
})
public class PARTGREENHOUSEGASID_Type {

    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "GREENHOUSEGASID", required = true)
    protected GREENHOUSEGASID_Type greenhousegasid;

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété greenhousegasid.
     * 
     * @return
     *     possible object is
     *     {@link GREENHOUSEGASID_Type }
     *     
     */
    public GREENHOUSEGASID_Type getGREENHOUSEGASID() {
        return greenhousegasid;
    }

    /**
     * Définit la valeur de la propriété greenhousegasid.
     * 
     * @param value
     *     allowed object is
     *     {@link GREENHOUSEGASID_Type }
     *     
     */
    public void setGREENHOUSEGASID(GREENHOUSEGASID_Type value) {
        this.greenhousegasid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PARTGREENHOUSEGASID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTGREENHOUSEGASID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTGREENHOUSEGASID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GREENHOUSEGASID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTGREENHOUSEGASID_Type", propOrder = {
    "partid",
    "greenhousegasid"
})
public class PARTGREENHOUSEGASID_Type {

    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "GREENHOUSEGASID", required = true)
    protected GREENHOUSEGASID_Type greenhousegasid;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the greenhousegasid property.
     * 
     * @return
     *     possible object is
     *     {@link GREENHOUSEGASID_Type }
     *     
     */
    public GREENHOUSEGASID_Type getGREENHOUSEGASID() {
        return greenhousegasid;
    }

    /**
     * Sets the value of the greenhousegasid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GREENHOUSEGASID_Type }
     *     
     */
    public void setGREENHOUSEGASID(GREENHOUSEGASID_Type value) {
        this.greenhousegasid = value;
    }

}
